This library contains many useful function which will speed up the making of scrappers. The library focusses on efforts to ensure that the scrappers don't get blocked by the servers. It has functions which:
- Returns a random user agent out of 10,000 user agents. The user agents are stored in a csv file inside the package.
- Randomly hit various URLs provided by the users
- Raise Alert in the form of e-mail and/or beeps 